@@ -105,10 +105,11 @@ def load_dataset(filenames, labeled = True, ordered = False):
 
 def get_training_dataset(GCS_DS_PATH, train_tfrec_path, BATCH_SIZE, augmentation = False):
 	
-	print(""" Make Sure to
-	Define how to read LABELED tfrecord data as per the LABELED_TFRECORD_FORMAT
-	Rest of the helper functions are implemented.
-	""")
+	if not augmentation:
+		print(""" Make Sure to
+		Define how to read LABELED tfrecord data as per the LABELED_TFRECORD_FORMAT
+		Rest of the helper functions are implemented.
+		""")
 	dataset = load_dataset(tf.io.gfile.glob(GCS_DS_PATH  + train_tfrec_path), labeled = True)
 	if augmentation:
 		from quick_ml.augments import augmentations
@@ -116,19 +117,23 @@ def get_training_dataset(GCS_DS_PATH, train_tfrec_path, BATCH_SIZE, augmentation
 	cnt = 0
 	for data in dataset:
 		cnt += 1
-	print(f"Loaded {train_tfrec_path} with {cnt} examples")
+	if not augmentation:
+		print(f"Loaded {train_tfrec_path} with {cnt} examples")
 	dataset = dataset.repeat()
 	dataset = dataset.shuffle(2048)
 	dataset = dataset.batch(BATCH_SIZE)
+	dataset = dataset.prefetch(tf.data.experimental.AUTOTUNE)
 	return dataset
 
 
 def get_validation_dataset(GCS_DS_PATH,val_tfrec_path, BATCH_SIZE , augmentation = False):
 	
-	print(""" Make Sure to
-	Define how to read LABELED tfrecord data as per the LABELED_TFRECORD_FORMAT
-	Rest of the helper functions are implemented.
-	""")
+	
+	if not augmentation:
+		print(""" Make Sure to
+		Define how to read LABELED tfrecord data as per the LABELED_TFRECORD_FORMAT
+		Rest of the helper functions are implemented.
+		""")
 	
 	dataset = load_dataset(tf.io.gfile.glob(GCS_DS_PATH + val_tfrec_path), labeled = True, ordered = False)
 	
@@ -138,9 +143,11 @@ def get_validation_dataset(GCS_DS_PATH,val_tfrec_path, BATCH_SIZE , augmentation
 	cnt = 0
 	for data in dataset:
 		cnt += 1
-	print(f"Loaded {val_tfrec_path} with {cnt} examples")
+	if not augmentation:
+		print(f"Loaded {val_tfrec_path} with {cnt} examples")
 	dataset = dataset.batch(BATCH_SIZE)
 	dataset = dataset.cache()
+	dataset = dataset.prefetch(tf.data.experimental.AUTOTUNE)
 	
 	return dataset
 
